@@ -47,14 +47,14 @@ impl Encoding for GB18030Encoding {
 pub struct GB18030Encoder;
 
 impl GB18030Encoder {
-    pub fn new() -> Box<RawEncoder> { box GB18030Encoder as Box<RawEncoder> }
+    pub fn new() -> Box<RawEncoder> { Box::new(GB18030Encoder) }
 }
 
 impl RawEncoder for GB18030Encoder {
     fn from_self(&self) -> Box<RawEncoder> { GB18030Encoder::new() }
     fn is_ascii_compatible(&self) -> bool { true }
 
-    fn raw_feed(&mut self, input: &str, output: &mut ByteWriter) -> (uint, Option<CodecError>) {
+    fn raw_feed(&mut self, input: &str, output: &mut ByteWriter) -> (usize, Option<CodecError>) {
         output.writer_hint(input.len());
 
         for ch in input.chars() {
@@ -99,8 +99,8 @@ ascii_compatible_stateful_decoder! {
     internal pub fn map_two_bytes(lead: u8, trail: u8) -> u32 {
         use index_simpchinese as index;
 
-        let lead = lead as uint;
-        let trail = trail as uint;
+        let lead = lead as u16;
+        let trail = trail as u16;
         let index = match (lead, trail) {
             (0x81...0xfe, 0x40...0x7e) | (0x81...0xfe, 0x80...0xfe) => {
                 let trailoffset = if trail < 0x7f {0x40} else {0x41};
@@ -108,28 +108,30 @@ ascii_compatible_stateful_decoder! {
             }
             _ => 0xffff,
         };
-        index::gb18030::forward(index as u16)
+        index::gb18030::forward(index)
     }
 
     internal pub fn map_four_bytes(b1: u8, b2: u8, b3: u8, b4: u8) -> u32 {
         use index_simpchinese as index;
 
         // no range check here, caller should have done all checks
-        let index = (b1 as uint - 0x81) * 12600 + (b2 as uint - 0x30) * 1260 +
-                    (b3 as uint - 0x81) * 10 + (b4 as uint - 0x30);
-        index::gb18030_ranges::forward(index as u32)
+        let index = (b1 as u32 - 0x81) * 12600 + (b2 as u32 - 0x30) * 1260 +
+                    (b3 as u32 - 0x81) * 10 + (b4 as u32 - 0x30);
+        index::gb18030_ranges::forward(index)
     }
 
+initial:
     // gb18030 first = 0x00, gb18030 second = 0x00, gb18030 third = 0x00
-    initial state S0(ctx) {
+    state S0(ctx: Context) {
         case b @ 0x00...0x7f => ctx.emit(b as u32);
         case 0x80 => ctx.emit(0x20ac);
         case b @ 0x81...0xfe => S1(ctx, b);
         case _ => ctx.err("invalid sequence");
     }
 
+transient:
     // gb18030 first != 0x00, gb18030 second = 0x00, gb18030 third = 0x00
-    state S1(ctx, first: u8) {
+    state S1(ctx: Context, first: u8) {
         case b @ 0x30...0x39 => S2(ctx, first, b);
         case b => match map_two_bytes(first, b) {
             0xffff => ctx.backup_and_err(1, "invalid sequence"), // unconditional
@@ -138,13 +140,13 @@ ascii_compatible_stateful_decoder! {
     }
 
     // gb18030 first != 0x00, gb18030 second != 0x00, gb18030 third = 0x00
-    state S2(ctx, first: u8, second: u8) {
+    state S2(ctx: Context, first: u8, second: u8) {
         case b @ 0x81...0xfe => S3(ctx, first, second, b);
         case _ => ctx.backup_and_err(2, "invalid sequence");
     }
 
     // gb18030 first != 0x00, gb18030 second != 0x00, gb18030 third != 0x00
-    state S3(ctx, first: u8, second: u8, third: u8) {
+    state S3(ctx: Context, first: u8, second: u8, third: u8) {
         case b @ 0x30...0x39 => match map_four_bytes(first, second, third, b) {
             0xffffffff => ctx.backup_and_err(3, "invalid sequence"), // unconditional
             ch => ctx.emit(ch)
@@ -306,7 +308,7 @@ mod gb18030_tests {
         let s = testutils::SIMPLIFIED_CHINESE_TEXT;
         bencher.bytes = s.len() as u64;
         bencher.iter(|| test::black_box({
-            GB18030Encoding.encode(s[], EncoderTrap::Strict)
+            GB18030Encoding.encode(&s[], EncoderTrap::Strict)
         }))
     }
 
@@ -316,7 +318,7 @@ mod gb18030_tests {
                                        EncoderTrap::Strict).ok().unwrap();
         bencher.bytes = s.len() as u64;
         bencher.iter(|| test::black_box({
-            GB18030Encoding.decode(s[], DecoderTrap::Strict)
+            GB18030Encoding.decode(&s[], DecoderTrap::Strict)
         }))
     }
 }
@@ -347,14 +349,14 @@ pub struct HZEncoder {
 }
 
 impl HZEncoder {
-    pub fn new() -> Box<RawEncoder> { box HZEncoder { escaped: false } as Box<RawEncoder> }
+    pub fn new() -> Box<RawEncoder> { Box::new(HZEncoder { escaped: false }) }
 }
 
 impl RawEncoder for HZEncoder {
     fn from_self(&self) -> Box<RawEncoder> { HZEncoder::new() }
     fn is_ascii_compatible(&self) -> bool { false }
 
-    fn raw_feed(&mut self, input: &str, output: &mut ByteWriter) -> (uint, Option<CodecError>) {
+    fn raw_feed(&mut self, input: &str, output: &mut ByteWriter) -> (usize, Option<CodecError>) {
         output.writer_hint(input.len());
 
         let mut escaped = self.escaped;
@@ -375,7 +377,7 @@ impl RawEncoder for HZEncoder {
                 if ptr == 0xffff {
                     self.escaped = escaped; // do NOT reset the state!
                     return (i, Some(CodecError {
-                        upto: j as int, cause: "unrepresentable character".into_cow()
+                        upto: j as isize, cause: "unrepresentable character".into_cow()
                     }));
                 } else {
                     let lead = ptr / 190;
@@ -383,7 +385,7 @@ impl RawEncoder for HZEncoder {
                     if lead < 0x21 - 1 || trail < 0x21 + 0x3f { // GBK extension, ignored
                         self.escaped = escaped; // do NOT reset the state!
                         return (i, Some(CodecError {
-                            upto: j as int, cause: "unrepresentable character".into_cow()
+                            upto: j as isize, cause: "unrepresentable character".into_cow()
                         }));
                     } else {
                         ensure_escaped!();
@@ -415,25 +417,27 @@ stateful_decoder! {
     internal pub fn map_two_bytes(lead: u8, trail: u8) -> u32 {
         use index_simpchinese as index;
 
-        let lead = lead as uint;
-        let trail = trail as uint;
+        let lead = lead as u16;
+        let trail = trail as u16;
         let index = match (lead, trail) {
             (0x20...0x7f, 0x21...0x7e) => (lead - 1) * 190 + (trail + 0x3f),
             _ => 0xffff,
         };
-        index::gb18030::forward(index as u16)
+        index::gb18030::forward(index)
     }
 
+initial:
     // hz-gb-2312 flag = unset, hz-gb-2312 lead = 0x00
-    initial state A0(ctx) {
+    state A0(ctx: Context) {
         case 0x7e => A1(ctx);
         case b @ 0x00...0x7f => ctx.emit(b as u32);
         case _ => ctx.err("invalid sequence");
         final => ctx.reset();
     }
 
+checkpoint:
     // hz-gb-2312 flag = set, hz-gb-2312 lead = 0x00
-    checkpoint state B0(ctx) {
+    state B0(ctx: Context) {
         case 0x7e => B1(ctx);
         case b @ 0x20...0x7f => B2(ctx, b);
         case 0x0a => ctx.err("invalid sequence"); // error *and* reset
@@ -441,8 +445,9 @@ stateful_decoder! {
         final => ctx.reset();
     }
 
+transient:
     // hz-gb-2312 flag = unset, hz-gb-2312 lead = 0x7e
-    state A1(ctx) {
+    state A1(ctx: Context) {
         case 0x7b => B0(ctx);
         case 0x7d => A0(ctx);
         case 0x7e => ctx.emit(0x7e), A0(ctx);
@@ -452,7 +457,7 @@ stateful_decoder! {
     }
 
     // hz-gb-2312 flag = set, hz-gb-2312 lead = 0x7e
-    state B1(ctx) {
+    state B1(ctx: Context) {
         case 0x7b => B0(ctx);
         case 0x7d => A0(ctx);
         case 0x7e => ctx.emit(0x7e), B0(ctx);
@@ -462,7 +467,7 @@ stateful_decoder! {
     }
 
     // hz-gb-2312 flag = set, hz-gb-2312 lead != 0 & != 0x7e
-    state B2(ctx, lead: u8) {
+    state B2(ctx: Context, lead: u8) {
         case 0x0a => ctx.err("invalid sequence"); // should reset the state!
         case b =>
             match map_two_bytes(lead, b) {
@@ -596,7 +601,7 @@ mod hz_tests {
         let s = testutils::SIMPLIFIED_CHINESE_TEXT;
         bencher.bytes = s.len() as u64;
         bencher.iter(|| test::black_box({
-            HZEncoding.encode(s[], EncoderTrap::Strict)
+            HZEncoding.encode(&s[], EncoderTrap::Strict)
         }))
     }
 
@@ -606,7 +611,7 @@ mod hz_tests {
                                   EncoderTrap::Strict).ok().unwrap();
         bencher.bytes = s.len() as u64;
         bencher.iter(|| test::black_box({
-            HZEncoding.decode(s[], DecoderTrap::Strict)
+            HZEncoding.decode(&s[], DecoderTrap::Strict)
         }))
     }
 }
